@@ -24,18 +24,21 @@ from utils import *
 from batchretrieve import *
 
 if __name__ == "__main__":
-    JIR = autoclass('org.terrier.querying.IndexRef')
-    indexref = JIR.of("../index/data.properties")
+    # JIR = autoclass('org.terrier.querying.IndexRef')
+    # indexref = JIR.of("../index/data.properties")
+    index_path = "../index/data.properties"
+
     topics = Utils.parse_trec_topics_file("../vaswani_npl/query-text.trec")
     topics_light = Utils.parse_trec_topics_file("../vaswani_npl/query_light.trec")
 
-    feat_retrieve = FeaturesBatchRetrieve(indexref, ["WMODEL:BM25","WMODEL:PL2"])
-    feat_res = feat_retrieve.transform(topics_light)
-    print(feat_res)
+    # feat_retrieve = FeaturesBatchRetrieve(index_path, ["WMODEL:BM25","WMODEL:PL2"])
+    # feat_res = feat_retrieve.transform(topics_light)
+    # print(feat_res)
+
+    retr = BatchRetrieve(index_path)
+    batch_retrieve_results=retr.transform(["light","dark"])
+    print(batch_retrieve_results)
 
-    # retr = BatchRetrieve(indexref)
-    # batch_retrieve_results=retr.transform(topics_light)
-    # print(batch_retrieve_results)
     # retr.saveLastResult("dph.res")
     # retr.saveResult(batch_retrieve_results,"/home/alex/Documents/Pyterrier/result.res")
 
